# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.get_seller_response

class GetOrderItemResponse(object):

    """Implementation of the 'GetOrderItemResponse' model.

    Response object for getting an order item

    Attributes:
        id (string): Id
        amount (int): TODO: type description here.
        description (string): TODO: type description here.
        quantity (int): TODO: type description here.
        get_seller_response (GetSellerResponse): Seller data
        category (string): Category
        code (string): Code

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "amount":'amount',
        "description":'description',
        "quantity":'quantity',
        "category":'category',
        "code":'code',
        "get_seller_response":'GetSellerResponse'
    }

    def __init__(self,
                 id=None,
                 amount=None,
                 description=None,
                 quantity=None,
                 category=None,
                 code=None,
                 get_seller_response=None):
        """Constructor for the GetOrderItemResponse class"""

        # Initialize members of the class
        self.id = id
        self.amount = amount
        self.description = description
        self.quantity = quantity
        self.get_seller_response = get_seller_response
        self.category = category
        self.code = code


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        amount = dictionary.get('amount')
        description = dictionary.get('description')
        quantity = dictionary.get('quantity')
        category = dictionary.get('category')
        code = dictionary.get('code')
        get_seller_response = pagarmecoreapi.models.get_seller_response.GetSellerResponse.from_dictionary(dictionary.get('GetSellerResponse')) if dictionary.get('GetSellerResponse') else None

        # Return an object of this model
        return cls(id,
                   amount,
                   description,
                   quantity,
                   category,
                   code,
                   get_seller_response)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateSplitOptionsRequest(object):

    """Implementation of the 'CreateSplitOptionsRequest' model.

    The Split Options Request

    Attributes:
        liable (bool): Liable options
        charge_processing_fee (bool): Charge processing fee
        charge_remainder_fee (bool): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "liable":'liable',
        "charge_processing_fee":'charge_processing_fee',
        "charge_remainder_fee":'charge_remainder_fee'
    }

    def __init__(self,
                 liable=None,
                 charge_processing_fee=None,
                 charge_remainder_fee=None):
        """Constructor for the CreateSplitOptionsRequest class"""

        # Initialize members of the class
        self.liable = liable
        self.charge_processing_fee = charge_processing_fee
        self.charge_remainder_fee = charge_remainder_fee


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        liable = dictionary.get('liable')
        charge_processing_fee = dictionary.get('charge_processing_fee')
        charge_remainder_fee = dictionary.get('charge_remainder_fee')

        # Return an object of this model
        return cls(liable,
                   charge_processing_fee,
                   charge_remainder_fee)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper
import pagarmecoreapi.models.create_address_request

class CreateBoletoPaymentRequest(object):

    """Implementation of the 'CreateBoletoPaymentRequest' model.

    Contains the settings for creating a boleto payment

    Attributes:
        retries (int): Number of retries
        bank (string): The bank code, containing three characters. The
            available codes are on the API specification
        instructions (string): The instructions field that will be printed on
            the boleto.
        due_at (datetime): Boleto due date
        billing_address (CreateAddressRequest): Card's billing address
        billing_address_id (string): The address id for the billing address
        nosso_numero (string): Customer identification number with the bank
        document_number (string): Boleto identification

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "retries":'retries',
        "bank":'bank',
        "instructions":'instructions',
        "billing_address":'billing_address',
        "billing_address_id":'billing_address_id',
        "document_number":'document_number',
        "due_at":'due_at',
        "nosso_numero":'nosso_numero'
    }

    def __init__(self,
                 retries=None,
                 bank=None,
                 instructions=None,
                 billing_address=None,
                 billing_address_id=None,
                 document_number=None,
                 due_at=None,
                 nosso_numero=None):
        """Constructor for the CreateBoletoPaymentRequest class"""

        # Initialize members of the class
        self.retries = retries
        self.bank = bank
        self.instructions = instructions
        self.due_at = APIHelper.RFC3339DateTime(due_at) if due_at else None
        self.billing_address = billing_address
        self.billing_address_id = billing_address_id
        self.nosso_numero = nosso_numero
        self.document_number = document_number


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        retries = dictionary.get('retries')
        bank = dictionary.get('bank')
        instructions = dictionary.get('instructions')
        billing_address = pagarmecoreapi.models.create_address_request.CreateAddressRequest.from_dictionary(dictionary.get('billing_address')) if dictionary.get('billing_address') else None
        billing_address_id = dictionary.get('billing_address_id')
        document_number = dictionary.get('document_number')
        due_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("due_at")).datetime if dictionary.get("due_at") else None
        nosso_numero = dictionary.get('nosso_numero')

        # Return an object of this model
        return cls(retries,
                   bank,
                   instructions,
                   billing_address,
                   billing_address_id,
                   document_number,
                   due_at,
                   nosso_numero)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class GetWithdrawSourceResponse(object):

    """Implementation of the 'GetWithdrawSourceResponse' model.

    TODO: type model description here.

    Attributes:
        source_id (string): TODO: type description here.
        mtype (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "source_id":'source_id',
        "mtype":'type'
    }

    def __init__(self,
                 source_id=None,
                 mtype=None):
        """Constructor for the GetWithdrawSourceResponse class"""

        # Initialize members of the class
        self.source_id = source_id
        self.mtype = mtype


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        source_id = dictionary.get('source_id')
        mtype = dictionary.get('type')

        # Return an object of this model
        return cls(source_id,
                   mtype)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_cancel_charge_split_rules_request
import pagarmecoreapi.models.create_split_request

class CreateCancelChargeRequest(object):

    """Implementation of the 'CreateCancelChargeRequest' model.

    Request for canceling a charge.

    Attributes:
        amount (int): The amount that will be canceled.
        split_rules (list of CreateCancelChargeSplitRulesRequest): The split
            rules request
        split (list of CreateSplitRequest): Splits
        operation_reference (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "operation_reference":'operation_reference',
        "amount":'amount',
        "split_rules":'split_rules',
        "split":'split'
    }

    def __init__(self,
                 operation_reference=None,
                 amount=None,
                 split_rules=None,
                 split=None):
        """Constructor for the CreateCancelChargeRequest class"""

        # Initialize members of the class
        self.amount = amount
        self.split_rules = split_rules
        self.split = split
        self.operation_reference = operation_reference


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        operation_reference = dictionary.get('operation_reference')
        amount = dictionary.get('amount')
        split_rules = None
        if dictionary.get('split_rules') != None:
            split_rules = list()
            for structure in dictionary.get('split_rules'):
                split_rules.append(pagarmecoreapi.models.create_cancel_charge_split_rules_request.CreateCancelChargeSplitRulesRequest.from_dictionary(structure))
        split = None
        if dictionary.get('split') != None:
            split = list()
            for structure in dictionary.get('split'):
                split.append(pagarmecoreapi.models.create_split_request.CreateSplitRequest.from_dictionary(structure))

        # Return an object of this model
        return cls(operation_reference,
                   amount,
                   split_rules,
                   split)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateCardPaymentContactlessPOIRequest(object):

    """Implementation of the 'CreateCardPaymentContactlessPOIRequest' model.

    TODO: type model description here.

    Attributes:
        system_name (string): system name
        model (string): model
        provider (string): provider
        serial_number (string): serial number
        version_number (string): version number

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "system_name":'system_name',
        "model":'model',
        "provider":'provider',
        "serial_number":'serial_number',
        "version_number":'version_number'
    }

    def __init__(self,
                 system_name=None,
                 model=None,
                 provider=None,
                 serial_number=None,
                 version_number=None):
        """Constructor for the CreateCardPaymentContactlessPOIRequest class"""

        # Initialize members of the class
        self.system_name = system_name
        self.model = model
        self.provider = provider
        self.serial_number = serial_number
        self.version_number = version_number


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        system_name = dictionary.get('system_name')
        model = dictionary.get('model')
        provider = dictionary.get('provider')
        serial_number = dictionary.get('serial_number')
        version_number = dictionary.get('version_number')

        # Return an object of this model
        return cls(system_name,
                   model,
                   provider,
                   serial_number,
                   version_number)





__all__ = [
    'list_invoices_response',
    'get_checkout_boleto_payment_response',
    'create_card_options_request',
    'update_subscription_billing_date_request',
    'list_charges_response',
    'list_subscriptions_response',
    'paging_response',
    'list_transactions_response',
    'get_plan_item_response',
    'get_phones_response',
    'create_card_token_request',
    'list_cards_response',
    'get_pricing_scheme_response',
    'get_price_bracket_response',
    'get_token_response',
    'list_customers_response',
    'update_plan_item_request',
    'update_subscription_item_request',
    'get_charge_response',
    'get_checkout_payment_settings_response',
    'list_plans_response',
    'get_order_response',
    'get_antifraud_response',
    'create_setup_request',
    'update_charge_card_request',
    'create_phone_request',
    'create_checkout_debit_card_payment_request',
    'create_plan_item_request',
    'create_capture_charge_request',
    'create_token_request',
    'update_metadata_request',
    'create_checkout_card_installment_option_request',
    'update_pricing_scheme_request',
    'list_access_tokens_response',
    'list_usages_response',
    'update_subscription_card_request',
    'get_setup_response',
    'get_plan_response',
    'update_plan_request',
    'create_price_bracket_request',
    'get_card_token_response',
    'get_checkout_card_installment_options_response',
    'create_pricing_scheme_request',
    'create_cancel_subscription_request',
    'update_card_request',
    'create_plan_request',
    'create_bank_transfer_payment_request',
    'create_phones_request',
    'create_voucher_payment_request',
    'create_checkout_boleto_payment_request',
    'update_charge_due_date_request',
    'list_subscription_items_response',
    'create_access_token_request',
    'get_phone_response',
    'list_order_response',
    'list_addresses_response',
    'get_discount_response',
    'get_customer_response',
    'create_address_request',
    'update_price_bracket_request',
    'get_seller_response',
    'create_subscription_item_request',
    'get_sellers_request',
    'create_order_request',
    'get_gateway_response_response',
    'create_device_request',
    'update_subscription_affiliation_id_request',
    'list_seller_response',
    'get_increment_response',
    'create_three_d_secure_request',
    'update_charge_payment_method_request',
    'get_recipient_response',
    'update_recipient_request',
    'create_anticipation_request',
    'get_anticipation_limits_response',
    'get_invoice_item_response',
    'create_discount_request',
    'get_card_response',
    'get_gateway_recipient_response',
    'list_increments_response',
    'create_bank_account_request',
    'get_balance_response',
    'update_order_item_request',
    'create_boleto_payment_request',
    'list_anticipation_response',
    'update_address_request',
    'get_subscription_item_response',
    'get_location_response',
    'create_transfer_settings_request',
    'get_gateway_error_response',
    'create_transfer_request',
    'get_billing_address_response',
    'list_transfer_response',
    'create_usage_request',
    'create_payment_authentication_request',
    'create_increment_request',
    'update_invoice_status_request',
    'get_anticipation_limit_response',
    'get_usage_response',
    'create_subscription_request',
    'create_apple_pay_request',
    'update_customer_request',
    'get_subscription_response',
    'get_period_response',
    'create_debit_card_payment_request',
    'create_apple_pay_header_request',
    'create_seller_request',
    'get_transfer_response',
    'create_location_request',
    'update_order_status_request',
    'create_credit_card_payment_request',
    'list_discounts_response',
    'create_recipient_request',
    'list_recipient_response',
    'get_device_response',
    'create_payment_request',
    'get_transaction_response',
    'update_recipient_bank_account_request',
    'update_seller_request',
    'update_transfer_settings_request',
    'create_cancel_charge_request',
    'update_subscription_start_at_request',
    'create_transaction_report_file_request',
    'create_card_request',
    'create_emv_data_dukpt_decrypt_request',
    'get_withdraw_target_response',
    'get_charges_summary_response',
    'create_private_label_payment_request',
    'update_automatic_anticipation_settings_request',
    'create_cash_payment_request',
    'create_confirm_payment_request',
    'create_shipping_request',
    'get_checkout_credit_card_payment_response',
    'create_charge_request',
    'create_transfer',
    'get_checkout_debit_card_payment_response',
    'get_anticipation_response',
    'create_automatic_anticipation_settings_request',
    'create_cancel_charge_split_rules_request',
    'get_split_response',
    'create_pix_payment_request',
    'list_transactions_files_response',
    'create_emv_data_tlv_decrypt_request',
    'create_emv_decrypt_request',
    'get_withdraw_source_response',
    'create_google_pay_request',
    'update_subscription_payment_method_request',
    'create_antifraud_request',
    'get_checkout_bank_transfer_payment_response',
    'get_bank_account_response',
    'update_subscription_minimum_price_request',
    'create_order_item_request',
    'create_split_options_request',
    'get_transaction_report_file_response',
    'create_clear_sale_request',
    'get_usage_report_response',
    'list_transfers',
    'pix_additional_information',
    'get_shipping_response',
    'create_checkout_bank_transfer_request',
    'create_card_payment_contactless_request',
    'create_customer_request',
    'get_transfer_target_response',
    'list_withdrawals',
    'update_current_cycle_end_date_request',
    'create_checkout_credit_card_payment_request',
    'get_checkout_payment_response',
    'create_emv_data_decrypt_request',
    'get_withdraw_response',
    'get_automatic_anticipation_response',
    'create_split_request',
    'update_current_cycle_status_request',
    'create_invoice_request',
    'get_transfer_settings_response',
    'create_checkout_payment_request',
    'create_period_request',
    'get_transfer',
    'get_three_d_secure_response',
    'create_google_pay_header_request',
    'get_order_item_response',
    'get_address_response',
    'create_card_payment_contactless_poi_request',
    'create_withdraw_request',
    'get_split_options_response',
    'get_payment_authentication_response',
    'list_charge_transactions_response',
    'list_cycles_response',
    'get_invoice_response',
    'get_access_token_response',
    'get_transfer_source_response',
    'create_sub_merchant_request',
    'update_subscription_due_days_request',
]


# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_payment_authentication_request

class CreateCheckoutDebitCardPaymentRequest(object):

    """Implementation of the 'CreateCheckoutDebitCardPaymentRequest' model.

    Checkout credit card payment request

    Attributes:
        statement_descriptor (string): Card invoice text descriptor
        authentication (CreatePaymentAuthenticationRequest): Creates payment
            authentication

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "authentication":'authentication',
        "statement_descriptor":'statement_descriptor'
    }

    def __init__(self,
                 authentication=None,
                 statement_descriptor=None):
        """Constructor for the CreateCheckoutDebitCardPaymentRequest class"""

        # Initialize members of the class
        self.statement_descriptor = statement_descriptor
        self.authentication = authentication


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        authentication = pagarmecoreapi.models.create_payment_authentication_request.CreatePaymentAuthenticationRequest.from_dictionary(dictionary.get('authentication')) if dictionary.get('authentication') else None
        statement_descriptor = dictionary.get('statement_descriptor')

        # Return an object of this model
        return cls(authentication,
                   statement_descriptor)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper
import pagarmecoreapi.models.get_card_token_response

class GetTokenResponse(object):

    """Implementation of the 'GetTokenResponse' model.

    Token data

    Attributes:
        id (string): TODO: type description here.
        mtype (string): TODO: type description here.
        created_at (datetime): TODO: type description here.
        expires_at (string): TODO: type description here.
        card (GetCardTokenResponse): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "mtype":'type',
        "created_at":'created_at',
        "expires_at":'expires_at',
        "card":'card'
    }

    def __init__(self,
                 id=None,
                 mtype=None,
                 created_at=None,
                 expires_at=None,
                 card=None):
        """Constructor for the GetTokenResponse class"""

        # Initialize members of the class
        self.id = id
        self.mtype = mtype
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.expires_at = expires_at
        self.card = card


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        mtype = dictionary.get('type')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        expires_at = dictionary.get('expires_at')
        card = pagarmecoreapi.models.get_card_token_response.GetCardTokenResponse.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None

        # Return an object of this model
        return cls(id,
                   mtype,
                   created_at,
                   expires_at,
                   card)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class GetLocationResponse(object):

    """Implementation of the 'GetLocationResponse' model.

    Response object for geetting an order location request

    Attributes:
        latitude (string): Latitude
        longitude (string): Longitude

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "latitude":'latitude',
        "longitude":'longitude'
    }

    def __init__(self,
                 latitude=None,
                 longitude=None):
        """Constructor for the GetLocationResponse class"""

        # Initialize members of the class
        self.latitude = latitude
        self.longitude = longitude


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        latitude = dictionary.get('latitude')
        longitude = dictionary.get('longitude')

        # Return an object of this model
        return cls(latitude,
                   longitude)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper

class CreateTransactionReportFileRequest(object):

    """Implementation of the 'CreateTransactionReportFileRequest' model.

    TODO: type model description here.

    Attributes:
        name (string): TODO: type description here.
        start_at (datetime): TODO: type description here.
        end_at (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "start_at":'start_at',
        "end_at":'end_at'
    }

    def __init__(self,
                 name=None,
                 start_at=None,
                 end_at=None):
        """Constructor for the CreateTransactionReportFileRequest class"""

        # Initialize members of the class
        self.name = name
        self.start_at = APIHelper.RFC3339DateTime(start_at) if start_at else None
        self.end_at = end_at


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        start_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("start_at")).datetime if dictionary.get("start_at") else None
        end_at = dictionary.get('end_at')

        # Return an object of this model
        return cls(name,
                   start_at,
                   end_at)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_emv_data_dukpt_decrypt_request
import pagarmecoreapi.models.create_emv_data_tlv_decrypt_request

class CreateEmvDataDecryptRequest(object):

    """Implementation of the 'CreateEmvDataDecryptRequest' model.

    TODO: type model description here.

    Attributes:
        cipher (string): Emv Decrypt cipher type
        dukpt (CreateEmvDataDukptDecryptRequest): Dukpt data request
        tags (list of CreateEmvDataTlvDecryptRequest): Encrypted tags list

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "cipher":'cipher',
        "tags":'tags',
        "dukpt":'dukpt'
    }

    def __init__(self,
                 cipher=None,
                 tags=None,
                 dukpt=None):
        """Constructor for the CreateEmvDataDecryptRequest class"""

        # Initialize members of the class
        self.cipher = cipher
        self.dukpt = dukpt
        self.tags = tags


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        cipher = dictionary.get('cipher')
        tags = None
        if dictionary.get('tags') != None:
            tags = list()
            for structure in dictionary.get('tags'):
                tags.append(pagarmecoreapi.models.create_emv_data_tlv_decrypt_request.CreateEmvDataTlvDecryptRequest.from_dictionary(structure))
        dukpt = pagarmecoreapi.models.create_emv_data_dukpt_decrypt_request.CreateEmvDataDukptDecryptRequest.from_dictionary(dictionary.get('dukpt')) if dictionary.get('dukpt') else None

        # Return an object of this model
        return cls(cipher,
                   tags,
                   dukpt)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateOrderStatusRequest(object):

    """Implementation of the 'UpdateOrderStatusRequest' model.

    TODO: type model description here.

    Attributes:
        status (string): Order status

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "status":'status'
    }

    def __init__(self,
                 status=None):
        """Constructor for the UpdateOrderStatusRequest class"""

        # Initialize members of the class
        self.status = status


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        status = dictionary.get('status')

        # Return an object of this model
        return cls(status)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class GetUsageReportResponse(object):

    """Implementation of the 'GetUsageReportResponse' model.

    TODO: type model description here.

    Attributes:
        url (string): TODO: type description here.
        usage_report_url (string): TODO: type description here.
        grouped_report_url (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "url":'url',
        "usage_report_url":'usage_report_url',
        "grouped_report_url":'grouped_report_url'
    }

    def __init__(self,
                 url=None,
                 usage_report_url=None,
                 grouped_report_url=None):
        """Constructor for the GetUsageReportResponse class"""

        # Initialize members of the class
        self.url = url
        self.usage_report_url = usage_report_url
        self.grouped_report_url = grouped_report_url


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        url = dictionary.get('url')
        usage_report_url = dictionary.get('usage_report_url')
        grouped_report_url = dictionary.get('grouped_report_url')

        # Return an object of this model
        return cls(url,
                   usage_report_url,
                   grouped_report_url)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.get_period_response
import pagarmecoreapi.models.list_usages_details_response

class GetUsagesDetailsResponse(object):

    """Implementation of the 'GetUsagesDetailsResponse' model.

    TODO: type model description here.

    Attributes:
        subscription_id (string): Subscription Identifier
        total_amount (int): Current Invoice Amount
        period (GetPeriodResponse): Period Details
        usages (ListUsagesDetailsResponse): Usages Details
        total_discount (int): Total discounted value
        total_increment (int): Total inremented value

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "subscription_id":'subscription_id',
        "total_amount":'total_amount',
        "usages":'Usages',
        "period":'Period',
        "total_discount":'total_discount',
        "total_increment":'total_increment'
    }

    def __init__(self,
                 subscription_id=None,
                 total_amount=None,
                 usages=None,
                 period=None,
                 total_discount=None,
                 total_increment=None):
        """Constructor for the GetUsagesDetailsResponse class"""

        # Initialize members of the class
        self.subscription_id = subscription_id
        self.total_amount = total_amount
        self.period = period
        self.usages = usages
        self.total_discount = total_discount
        self.total_increment = total_increment


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        subscription_id = dictionary.get('subscription_id')
        total_amount = dictionary.get('total_amount')
        usages = pagarmecoreapi.models.list_usages_details_response.ListUsagesDetailsResponse.from_dictionary(dictionary.get('Usages')) if dictionary.get('Usages') else None
        period = pagarmecoreapi.models.get_period_response.GetPeriodResponse.from_dictionary(dictionary.get('Period')) if dictionary.get('Period') else None
        total_discount = dictionary.get('total_discount')
        total_increment = dictionary.get('total_increment')

        # Return an object of this model
        return cls(subscription_id,
                   total_amount,
                   usages,
                   period,
                   total_discount,
                   total_increment)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper
import pagarmecoreapi.models.get_address_response

class GetShippingResponse(object):

    """Implementation of the 'GetShippingResponse' model.

    Response object for getting the shipping data

    Attributes:
        amount (int): TODO: type description here.
        description (string): TODO: type description here.
        recipient_name (string): TODO: type description here.
        recipient_phone (string): TODO: type description here.
        address (GetAddressResponse): TODO: type description here.
        max_delivery_date (datetime): Data máxima de entrega
        estimated_delivery_date (datetime): Prazo estimado de entrega
        mtype (string): Shipping Type

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount":'amount',
        "description":'description',
        "recipient_name":'recipient_name',
        "recipient_phone":'recipient_phone',
        "address":'address',
        "mtype":'type',
        "max_delivery_date":'max_delivery_date',
        "estimated_delivery_date":'estimated_delivery_date'
    }

    def __init__(self,
                 amount=None,
                 description=None,
                 recipient_name=None,
                 recipient_phone=None,
                 address=None,
                 mtype=None,
                 max_delivery_date=None,
                 estimated_delivery_date=None):
        """Constructor for the GetShippingResponse class"""

        # Initialize members of the class
        self.amount = amount
        self.description = description
        self.recipient_name = recipient_name
        self.recipient_phone = recipient_phone
        self.address = address
        self.max_delivery_date = APIHelper.RFC3339DateTime(max_delivery_date) if max_delivery_date else None
        self.estimated_delivery_date = APIHelper.RFC3339DateTime(estimated_delivery_date) if estimated_delivery_date else None
        self.mtype = mtype


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = dictionary.get('amount')
        description = dictionary.get('description')
        recipient_name = dictionary.get('recipient_name')
        recipient_phone = dictionary.get('recipient_phone')
        address = pagarmecoreapi.models.get_address_response.GetAddressResponse.from_dictionary(dictionary.get('address')) if dictionary.get('address') else None
        mtype = dictionary.get('type')
        max_delivery_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("max_delivery_date")).datetime if dictionary.get("max_delivery_date") else None
        estimated_delivery_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("estimated_delivery_date")).datetime if dictionary.get("estimated_delivery_date") else None

        # Return an object of this model
        return cls(amount,
                   description,
                   recipient_name,
                   recipient_phone,
                   address,
                   mtype,
                   max_delivery_date,
                   estimated_delivery_date)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper
from pagarmecoreapi.configuration import Configuration
from pagarmecoreapi.controllers.base_controller import BaseController
from pagarmecoreapi.http.auth.basic_auth import BasicAuth
from pagarmecoreapi.models.get_plan_response import GetPlanResponse
from pagarmecoreapi.models.get_plan_item_response import GetPlanItemResponse
from pagarmecoreapi.models.list_plans_response import ListPlansResponse

class PlansController(BaseController):

    """A Controller to access Endpoints in the pagarmecoreapi API."""


    def get_plan(self,
                 plan_id):
        """Does a GET request to /plans/{plan_id}.

        Gets a plan

        Args:
            plan_id (string): Plan id

        Returns:
            GetPlanResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans/{plan_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'plan_id': plan_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanResponse.from_dictionary)

    def delete_plan(self,
                    plan_id,
                    idempotency_key=None):
        """Does a DELETE request to /plans/{plan_id}.

        Deletes a plan

        Args:
            plan_id (string): Plan id
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetPlanResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans/{plan_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'plan_id': plan_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanResponse.from_dictionary)

    def update_plan_metadata(self,
                             plan_id,
                             request,
                             idempotency_key=None):
        """Does a PATCH request to /Plans/{plan_id}/metadata.

        Updates the metadata from a plan

        Args:
            plan_id (string): The plan id
            request (UpdateMetadataRequest): Request for updating the plan
                metadata
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetPlanResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/Plans/{plan_id}/metadata'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'plan_id': plan_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanResponse.from_dictionary)

    def update_plan_item(self,
                         plan_id,
                         plan_item_id,
                         body,
                         idempotency_key=None):
        """Does a PUT request to /plans/{plan_id}/items/{plan_item_id}.

        Updates a plan item

        Args:
            plan_id (string): Plan id
            plan_item_id (string): Plan item id
            body (UpdatePlanItemRequest): Request for updating the plan item
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetPlanItemResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans/{plan_id}/items/{plan_item_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'plan_id': plan_id,
            'plan_item_id': plan_item_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanItemResponse.from_dictionary)

    def create_plan_item(self,
                         plan_id,
                         request,
                         idempotency_key=None):
        """Does a POST request to /plans/{plan_id}/items.

        Adds a new item to a plan

        Args:
            plan_id (string): Plan id
            request (CreatePlanItemRequest): Request for creating a plan item
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetPlanItemResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans/{plan_id}/items'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'plan_id': plan_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanItemResponse.from_dictionary)

    def get_plan_item(self,
                      plan_id,
                      plan_item_id):
        """Does a GET request to /plans/{plan_id}/items/{plan_item_id}.

        Gets a plan item

        Args:
            plan_id (string): Plan id
            plan_item_id (string): Plan item id

        Returns:
            GetPlanItemResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans/{plan_id}/items/{plan_item_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'plan_id': plan_id,
            'plan_item_id': plan_item_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanItemResponse.from_dictionary)

    def create_plan(self,
                    body,
                    idempotency_key=None):
        """Does a POST request to /plans.

        Creates a new plan

        Args:
            body (CreatePlanRequest): Request for creating a plan
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetPlanResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanResponse.from_dictionary)

    def delete_plan_item(self,
                         plan_id,
                         plan_item_id,
                         idempotency_key=None):
        """Does a DELETE request to /plans/{plan_id}/items/{plan_item_id}.

        Removes an item from a plan

        Args:
            plan_id (string): Plan id
            plan_item_id (string): Plan item id
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetPlanItemResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans/{plan_id}/items/{plan_item_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'plan_id': plan_id,
            'plan_item_id': plan_item_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanItemResponse.from_dictionary)

    def get_plans(self,
                  page=None,
                  size=None,
                  name=None,
                  status=None,
                  billing_type=None,
                  created_since=None,
                  created_until=None):
        """Does a GET request to /plans.

        Gets all plans

        Args:
            page (int, optional): Page number
            size (int, optional): Page size
            name (string, optional): Filter for Plan's name
            status (string, optional): Filter for Plan's status
            billing_type (string, optional): Filter for plan's billing type
            created_since (datetime, optional): Filter for plan's creation
                date start range
            created_until (datetime, optional): Filter for plan's creation
                date end range

        Returns:
            ListPlansResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'page': page,
            'size': size,
            'name': name,
            'status': status,
            'billing_type': billing_type,
            'created_since': APIHelper.when_defined(APIHelper.RFC3339DateTime, created_since),
            'created_until': APIHelper.when_defined(APIHelper.RFC3339DateTime, created_until)
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListPlansResponse.from_dictionary)

    def update_plan(self,
                    plan_id,
                    request,
                    idempotency_key=None):
        """Does a PUT request to /plans/{plan_id}.

        Updates a plan

        Args:
            plan_id (string): Plan id
            request (UpdatePlanRequest): Request for updating a plan
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetPlanResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/plans/{plan_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'plan_id': plan_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPlanResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_emv_data_decrypt_request
import pagarmecoreapi.models.create_card_payment_contactless_poi_request

class CreateEmvDecryptRequest(object):

    """Implementation of the 'CreateEmvDecryptRequest' model.

    TODO: type model description here.

    Attributes:
        icc_data (string): TODO: type description here.
        card_sequence_number (string): TODO: type description here.
        data (CreateEmvDataDecryptRequest): TODO: type description here.
        poi (CreateCardPaymentContactlessPOIRequest): TODO: type description
            here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "icc_data":'icc_data',
        "card_sequence_number":'card_sequence_number',
        "data":'data',
        "poi":'poi'
    }

    def __init__(self,
                 icc_data=None,
                 card_sequence_number=None,
                 data=None,
                 poi=None):
        """Constructor for the CreateEmvDecryptRequest class"""

        # Initialize members of the class
        self.icc_data = icc_data
        self.card_sequence_number = card_sequence_number
        self.data = data
        self.poi = poi


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        icc_data = dictionary.get('icc_data')
        card_sequence_number = dictionary.get('card_sequence_number')
        data = pagarmecoreapi.models.create_emv_data_decrypt_request.CreateEmvDataDecryptRequest.from_dictionary(dictionary.get('data')) if dictionary.get('data') else None
        poi = pagarmecoreapi.models.create_card_payment_contactless_poi_request.CreateCardPaymentContactlessPOIRequest.from_dictionary(dictionary.get('poi')) if dictionary.get('poi') else None

        # Return an object of this model
        return cls(icc_data,
                   card_sequence_number,
                   data,
                   poi)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_credit_card_payment_request
import pagarmecoreapi.models.create_debit_card_payment_request
import pagarmecoreapi.models.create_boleto_payment_request
import pagarmecoreapi.models.create_voucher_payment_request
import pagarmecoreapi.models.create_cash_payment_request
import pagarmecoreapi.models.create_bank_transfer_payment_request
import pagarmecoreapi.models.create_private_label_payment_request

class UpdateChargePaymentMethodRequest(object):

    """Implementation of the 'UpdateChargePaymentMethodRequest' model.

    Request for updating the payment method of a charge

    Attributes:
        update_subscription (bool): Indicates if the payment method from the
            subscription must also be updated
        payment_method (string): The new payment method
        credit_card (CreateCreditCardPaymentRequest): Credit card data
        debit_card (CreateDebitCardPaymentRequest): Debit card data
        boleto (CreateBoletoPaymentRequest): Boleto data
        voucher (CreateVoucherPaymentRequest): Voucher data
        cash (CreateCashPaymentRequest): Cash data
        bank_transfer (CreateBankTransferPaymentRequest): Bank Transfer data
        private_label (CreatePrivateLabelPaymentRequest): TODO: type
            description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "update_subscription":'update_subscription',
        "payment_method":'payment_method',
        "credit_card":'credit_card',
        "debit_card":'debit_card',
        "boleto":'boleto',
        "voucher":'voucher',
        "cash":'cash',
        "bank_transfer":'bank_transfer',
        "private_label":'private_label'
    }

    def __init__(self,
                 update_subscription=None,
                 payment_method=None,
                 credit_card=None,
                 debit_card=None,
                 boleto=None,
                 voucher=None,
                 cash=None,
                 bank_transfer=None,
                 private_label=None):
        """Constructor for the UpdateChargePaymentMethodRequest class"""

        # Initialize members of the class
        self.update_subscription = update_subscription
        self.payment_method = payment_method
        self.credit_card = credit_card
        self.debit_card = debit_card
        self.boleto = boleto
        self.voucher = voucher
        self.cash = cash
        self.bank_transfer = bank_transfer
        self.private_label = private_label


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        update_subscription = dictionary.get('update_subscription')
        payment_method = dictionary.get('payment_method')
        credit_card = pagarmecoreapi.models.create_credit_card_payment_request.CreateCreditCardPaymentRequest.from_dictionary(dictionary.get('credit_card')) if dictionary.get('credit_card') else None
        debit_card = pagarmecoreapi.models.create_debit_card_payment_request.CreateDebitCardPaymentRequest.from_dictionary(dictionary.get('debit_card')) if dictionary.get('debit_card') else None
        boleto = pagarmecoreapi.models.create_boleto_payment_request.CreateBoletoPaymentRequest.from_dictionary(dictionary.get('boleto')) if dictionary.get('boleto') else None
        voucher = pagarmecoreapi.models.create_voucher_payment_request.CreateVoucherPaymentRequest.from_dictionary(dictionary.get('voucher')) if dictionary.get('voucher') else None
        cash = pagarmecoreapi.models.create_cash_payment_request.CreateCashPaymentRequest.from_dictionary(dictionary.get('cash')) if dictionary.get('cash') else None
        bank_transfer = pagarmecoreapi.models.create_bank_transfer_payment_request.CreateBankTransferPaymentRequest.from_dictionary(dictionary.get('bank_transfer')) if dictionary.get('bank_transfer') else None
        private_label = pagarmecoreapi.models.create_private_label_payment_request.CreatePrivateLabelPaymentRequest.from_dictionary(dictionary.get('private_label')) if dictionary.get('private_label') else None

        # Return an object of this model
        return cls(update_subscription,
                   payment_method,
                   credit_card,
                   debit_card,
                   boleto,
                   voucher,
                   cash,
                   bank_transfer,
                   private_label)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateCancelChargeSplitRulesRequest(object):

    """Implementation of the 'CreateCancelChargeSplitRulesRequest' model.

    Creates a refund with split rules

    Attributes:
        id (string): The split rule gateway id
        amount (int): The split rule amount
        mtype (string): The amount type (flat ou percentage)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "amount":'Amount',
        "mtype":'type'
    }

    def __init__(self,
                 id=None,
                 amount=None,
                 mtype=None):
        """Constructor for the CreateCancelChargeSplitRulesRequest class"""

        # Initialize members of the class
        self.id = id
        self.amount = amount
        self.mtype = mtype


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        amount = dictionary.get('Amount')
        mtype = dictionary.get('type')

        # Return an object of this model
        return cls(id,
                   amount,
                   mtype)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_phone_request
import pagarmecoreapi.models.create_address_request

class CreateSubMerchantRequest(object):

    """Implementation of the 'CreateSubMerchantRequest' model.

    SubMerchant

    Attributes:
        payment_facilitator_code (string): Payment Facilitator Code
        code (string): Code
        name (string): Name
        merchant_category_code (string): Merchant Category Code
        document (string): Document number. Only numbers, no special
            characters.
        mtype (string): Document type. Can be either 'individual' or
            'company'
        phone (CreatePhoneRequest): Phone
        address (CreateAddressRequest): Address

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_facilitator_code":'payment_facilitator_code',
        "code":'code',
        "name":'name',
        "merchant_category_code":'merchant_category_code',
        "document":'document',
        "mtype":'type',
        "phone":'phone',
        "address":'address'
    }

    def __init__(self,
                 payment_facilitator_code=None,
                 code=None,
                 name=None,
                 merchant_category_code=None,
                 document=None,
                 mtype=None,
                 phone=None,
                 address=None):
        """Constructor for the CreateSubMerchantRequest class"""

        # Initialize members of the class
        self.payment_facilitator_code = payment_facilitator_code
        self.code = code
        self.name = name
        self.merchant_category_code = merchant_category_code
        self.document = document
        self.mtype = mtype
        self.phone = phone
        self.address = address


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_facilitator_code = dictionary.get('payment_facilitator_code')
        code = dictionary.get('code')
        name = dictionary.get('name')
        merchant_category_code = dictionary.get('merchant_category_code')
        document = dictionary.get('document')
        mtype = dictionary.get('type')
        phone = pagarmecoreapi.models.create_phone_request.CreatePhoneRequest.from_dictionary(dictionary.get('phone')) if dictionary.get('phone') else None
        address = pagarmecoreapi.models.create_address_request.CreateAddressRequest.from_dictionary(dictionary.get('address')) if dictionary.get('address') else None

        # Return an object of this model
        return cls(payment_facilitator_code,
                   code,
                   name,
                   merchant_category_code,
                   document,
                   mtype,
                   phone,
                   address)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateAutomaticAnticipationSettingsRequest(object):

    """Implementation of the 'CreateAutomaticAnticipationSettingsRequest' model.

    TODO: type model description here.

    Attributes:
        enabled (bool): TODO: type description here.
        mtype (string): TODO: type description here.
        volume_percentage (int): TODO: type description here.
        delay (int): TODO: type description here.
        days (list of int): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "enabled":'enabled',
        "mtype":'type',
        "volume_percentage":'volume_percentage',
        "delay":'delay',
        "days":'days'
    }

    def __init__(self,
                 enabled=None,
                 mtype=None,
                 volume_percentage=None,
                 delay=None,
                 days=None):
        """Constructor for the CreateAutomaticAnticipationSettingsRequest class"""

        # Initialize members of the class
        self.enabled = enabled
        self.mtype = mtype
        self.volume_percentage = volume_percentage
        self.delay = delay
        self.days = days


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        enabled = dictionary.get('enabled')
        mtype = dictionary.get('type')
        volume_percentage = dictionary.get('volume_percentage')
        delay = dictionary.get('delay')
        days = dictionary.get('days')

        # Return an object of this model
        return cls(enabled,
                   mtype,
                   volume_percentage,
                   delay,
                   days)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper

class CreateUsageRequest(object):

    """Implementation of the 'CreateUsageRequest' model.

    Request for creating a usage

    Attributes:
        quantity (int): TODO: type description here.
        description (string): TODO: type description here.
        used_at (datetime): TODO: type description here.
        code (string): Identification code in the client system
        group (string): identification group in the client system
        amount (int): Field used in item scheme type 'Percent'

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "quantity":'quantity',
        "description":'description',
        "used_at":'used_at',
        "code":'code',
        "group":'group',
        "amount":'amount'
    }

    def __init__(self,
                 quantity=None,
                 description=None,
                 used_at=None,
                 code=None,
                 group=None,
                 amount=None):
        """Constructor for the CreateUsageRequest class"""

        # Initialize members of the class
        self.quantity = quantity
        self.description = description
        self.used_at = APIHelper.RFC3339DateTime(used_at) if used_at else None
        self.code = code
        self.group = group
        self.amount = amount


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        quantity = dictionary.get('quantity')
        description = dictionary.get('description')
        used_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("used_at")).datetime if dictionary.get("used_at") else None
        code = dictionary.get('code')
        group = dictionary.get('group')
        amount = dictionary.get('amount')

        # Return an object of this model
        return cls(quantity,
                   description,
                   used_at,
                   code,
                   group,
                   amount)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.get_recipient_response
import pagarmecoreapi.models.get_split_options_response

class GetSplitResponse(object):

    """Implementation of the 'GetSplitResponse' model.

    Split response

    Attributes:
        mtype (string): Type
        amount (int): Amount
        recipient (GetRecipientResponse): Recipient
        gateway_id (string): The split rule gateway id
        options (GetSplitOptionsResponse): TODO: type description here.
        id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "amount":'amount',
        "gateway_id":'gateway_id',
        "id":'id',
        "recipient":'recipient',
        "options":'options'
    }

    def __init__(self,
                 mtype=None,
                 amount=None,
                 gateway_id=None,
                 id=None,
                 recipient=None,
                 options=None):
        """Constructor for the GetSplitResponse class"""

        # Initialize members of the class
        self.mtype = mtype
        self.amount = amount
        self.recipient = recipient
        self.gateway_id = gateway_id
        self.options = options
        self.id = id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get('type')
        amount = dictionary.get('amount')
        gateway_id = dictionary.get('gateway_id')
        id = dictionary.get('id')
        recipient = pagarmecoreapi.models.get_recipient_response.GetRecipientResponse.from_dictionary(dictionary.get('recipient')) if dictionary.get('recipient') else None
        options = pagarmecoreapi.models.get_split_options_response.GetSplitOptionsResponse.from_dictionary(dictionary.get('options')) if dictionary.get('options') else None

        # Return an object of this model
        return cls(mtype,
                   amount,
                   gateway_id,
                   id,
                   recipient,
                   options)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper
from pagarmecoreapi.configuration import Configuration
from pagarmecoreapi.controllers.base_controller import BaseController
from pagarmecoreapi.http.auth.basic_auth import BasicAuth
from pagarmecoreapi.models.get_invoice_response import GetInvoiceResponse
from pagarmecoreapi.models.list_invoices_response import ListInvoicesResponse

class InvoicesController(BaseController):

    """A Controller to access Endpoints in the pagarmecoreapi API."""


    def update_invoice_metadata(self,
                                invoice_id,
                                request,
                                idempotency_key=None):
        """Does a PATCH request to /invoices/{invoice_id}/metadata.

        Updates the metadata from an invoice

        Args:
            invoice_id (string): The invoice id
            request (UpdateMetadataRequest): Request for updating the invoice
                metadata
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetInvoiceResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/invoices/{invoice_id}/metadata'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'invoice_id': invoice_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetInvoiceResponse.from_dictionary)

    def get_partial_invoice(self,
                            subscription_id):
        """Does a GET request to /subscriptions/{subscription_id}/partial-invoice.

        TODO: type endpoint description here.

        Args:
            subscription_id (string): Subscription Id

        Returns:
            GetInvoiceResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/subscriptions/{subscription_id}/partial-invoice'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'subscription_id': subscription_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetInvoiceResponse.from_dictionary)

    def cancel_invoice(self,
                       invoice_id,
                       idempotency_key=None):
        """Does a DELETE request to /invoices/{invoice_id}.

        Cancels an invoice

        Args:
            invoice_id (string): Invoice id
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetInvoiceResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/invoices/{invoice_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'invoice_id': invoice_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetInvoiceResponse.from_dictionary)

    def create_invoice(self,
                       subscription_id,
                       cycle_id,
                       request=None,
                       idempotency_key=None):
        """Does a POST request to /subscriptions/{subscription_id}/cycles/{cycle_id}/pay.

        Create an Invoice

        Args:
            subscription_id (string): Subscription Id
            cycle_id (string): Cycle Id
            request (CreateInvoiceRequest, optional): TODO: type description
                here. Example: 
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetInvoiceResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/subscriptions/{subscription_id}/cycles/{cycle_id}/pay'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'subscription_id': subscription_id,
            'cycle_id': cycle_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetInvoiceResponse.from_dictionary)

    def get_invoices(self,
                     page=None,
                     size=None,
                     code=None,
                     customer_id=None,
                     subscription_id=None,
                     created_since=None,
                     created_until=None,
                     status=None,
                     due_since=None,
                     due_until=None,
                     customer_document=None):
        """Does a GET request to /invoices.

        Gets all invoices

        Args:
            page (int, optional): Page number
            size (int, optional): Page size
            code (string, optional): Filter for Invoice's code
            customer_id (string, optional): Filter for Invoice's customer id
            subscription_id (string, optional): Filter for Invoice's
                subscription id
            created_since (datetime, optional): Filter for Invoice's creation
                date start range
            created_until (datetime, optional): Filter for Invoices creation
                date end range
            status (string, optional): Filter for Invoice's status
            due_since (datetime, optional): Filter for Invoice's due date
                start range
            due_until (datetime, optional): Filter for Invoice's due date end
                range
            customer_document (string, optional): TODO: type description here.
                Example: 

        Returns:
            ListInvoicesResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/invoices'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'page': page,
            'size': size,
            'code': code,
            'customer_id': customer_id,
            'subscription_id': subscription_id,
            'created_since': APIHelper.when_defined(APIHelper.RFC3339DateTime, created_since),
            'created_until': APIHelper.when_defined(APIHelper.RFC3339DateTime, created_until),
            'status': status,
            'due_since': APIHelper.when_defined(APIHelper.RFC3339DateTime, due_since),
            'due_until': APIHelper.when_defined(APIHelper.RFC3339DateTime, due_until),
            'customer_document': customer_document
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListInvoicesResponse.from_dictionary)

    def get_invoice(self,
                    invoice_id):
        """Does a GET request to /invoices/{invoice_id}.

        Gets an invoice

        Args:
            invoice_id (string): Invoice Id

        Returns:
            GetInvoiceResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/invoices/{invoice_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'invoice_id': invoice_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetInvoiceResponse.from_dictionary)

    def update_invoice_status(self,
                              invoice_id,
                              request,
                              idempotency_key=None):
        """Does a PATCH request to /invoices/{invoice_id}/status.

        Updates the status from an invoice

        Args:
            invoice_id (string): Invoice Id
            request (UpdateInvoiceStatusRequest): Request for updating an
                invoice's status
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetInvoiceResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/invoices/{invoice_id}/status'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'invoice_id': invoice_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetInvoiceResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateTransferSettingsRequest(object):

    """Implementation of the 'UpdateTransferSettingsRequest' model.

    TODO: type model description here.

    Attributes:
        transfer_enabled (string): TODO: type description here.
        transfer_interval (string): TODO: type description here.
        transfer_day (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transfer_enabled":'transfer_enabled',
        "transfer_interval":'transfer_interval',
        "transfer_day":'transfer_day'
    }

    def __init__(self,
                 transfer_enabled=None,
                 transfer_interval=None,
                 transfer_day=None):
        """Constructor for the UpdateTransferSettingsRequest class"""

        # Initialize members of the class
        self.transfer_enabled = transfer_enabled
        self.transfer_interval = transfer_interval
        self.transfer_day = transfer_day


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        transfer_enabled = dictionary.get('transfer_enabled')
        transfer_interval = dictionary.get('transfer_interval')
        transfer_day = dictionary.get('transfer_day')

        # Return an object of this model
        return cls(transfer_enabled,
                   transfer_interval,
                   transfer_day)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateApplePayHeaderRequest(object):

    """Implementation of the 'CreateApplePayHeaderRequest' model.

    The ApplePay header request

    Attributes:
        public_key_hash (string): SHA–256 hash, Base64 string codified
        ephemeral_public_key (string): X.509 encoded key bytes, Base64 encoded
            as a string
        transaction_id (string): Transaction identifier, generated on Device

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ephemeral_public_key":'ephemeral_public_key',
        "public_key_hash":'public_key_hash',
        "transaction_id":'transaction_id'
    }

    def __init__(self,
                 ephemeral_public_key=None,
                 public_key_hash=None,
                 transaction_id=None):
        """Constructor for the CreateApplePayHeaderRequest class"""

        # Initialize members of the class
        self.public_key_hash = public_key_hash
        self.ephemeral_public_key = ephemeral_public_key
        self.transaction_id = transaction_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        ephemeral_public_key = dictionary.get('ephemeral_public_key')
        public_key_hash = dictionary.get('public_key_hash')
        transaction_id = dictionary.get('transaction_id')

        # Return an object of this model
        return cls(ephemeral_public_key,
                   public_key_hash,
                   transaction_id)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateThreeDSecureRequest(object):

    """Implementation of the 'CreateThreeDSecureRequest' model.

    Creates a 3D-S authentication payment

    Attributes:
        mpi (string): The MPI Vendor (MerchantPlugin)
        cavv (string): The Cardholder Authentication Verification value
        eci (string): The Electronic Commerce Indicator value
        transaction_id (string): The TransactionId value (XID)
        success_url (string): The success URL after the authentication
        ds_transaction_id (string): Directory Service Transaction Identifier
        version (string): ThreeDSecure Version

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mpi":'mpi',
        "cavv":'cavv',
        "eci":'eci',
        "transaction_id":'transaction_id',
        "success_url":'success_url',
        "ds_transaction_id":'ds_transaction_id',
        "version":'version'
    }

    def __init__(self,
                 mpi=None,
                 cavv=None,
                 eci=None,
                 transaction_id=None,
                 success_url=None,
                 ds_transaction_id=None,
                 version=None):
        """Constructor for the CreateThreeDSecureRequest class"""

        # Initialize members of the class
        self.mpi = mpi
        self.cavv = cavv
        self.eci = eci
        self.transaction_id = transaction_id
        self.success_url = success_url
        self.ds_transaction_id = ds_transaction_id
        self.version = version


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mpi = dictionary.get('mpi')
        cavv = dictionary.get('cavv')
        eci = dictionary.get('eci')
        transaction_id = dictionary.get('transaction_id')
        success_url = dictionary.get('success_url')
        ds_transaction_id = dictionary.get('ds_transaction_id')
        version = dictionary.get('version')

        # Return an object of this model
        return cls(mpi,
                   cavv,
                   eci,
                   transaction_id,
                   success_url,
                   ds_transaction_id,
                   version)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateCashPaymentRequest(object):

    """Implementation of the 'CreateCashPaymentRequest' model.

    TODO: type model description here.

    Attributes:
        description (string): Description
        confirm (bool): Indicates whether cash collection will be confirmed in
            the act of creation

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "description":'description',
        "confirm":'confirm'
    }

    def __init__(self,
                 description=None,
                 confirm=None):
        """Constructor for the CreateCashPaymentRequest class"""

        # Initialize members of the class
        self.description = description
        self.confirm = confirm


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        description = dictionary.get('description')
        confirm = dictionary.get('confirm')

        # Return an object of this model
        return cls(description,
                   confirm)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_card_request

class CreateVoucherPaymentRequest(object):

    """Implementation of the 'CreateVoucherPaymentRequest' model.

    The settings for creating a voucher payment

    Attributes:
        statement_descriptor (string): The text that will be shown on the
            voucher's statement
        card_id (string): Card id
        card_token (string): Card token
        card (CreateCardRequest): Card info

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "statement_descriptor":'statement_descriptor',
        "card_id":'card_id',
        "card_token":'card_token',
        "card":'Card'
    }

    def __init__(self,
                 statement_descriptor=None,
                 card_id=None,
                 card_token=None,
                 card=None):
        """Constructor for the CreateVoucherPaymentRequest class"""

        # Initialize members of the class
        self.statement_descriptor = statement_descriptor
        self.card_id = card_id
        self.card_token = card_token
        self.card = card


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        statement_descriptor = dictionary.get('statement_descriptor')
        card_id = dictionary.get('card_id')
        card_token = dictionary.get('card_token')
        card = pagarmecoreapi.models.create_card_request.CreateCardRequest.from_dictionary(dictionary.get('Card')) if dictionary.get('Card') else None

        # Return an object of this model
        return cls(statement_descriptor,
                   card_id,
                   card_token,
                   card)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper
import pagarmecoreapi.models.get_withdraw_source_response
import pagarmecoreapi.models.get_withdraw_target_response

class GetWithdrawResponse(object):

    """Implementation of the 'GetWithdrawResponse' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        gateway_id (string): TODO: type description here.
        amount (int): TODO: type description here.
        status (string): TODO: type description here.
        created_at (datetime): TODO: type description here.
        updated_at (datetime): TODO: type description here.
        metadata (list of string): TODO: type description here.
        fee (int): TODO: type description here.
        funding_date (datetime): TODO: type description here.
        funding_estimated_date (datetime): TODO: type description here.
        mtype (string): TODO: type description here.
        source (GetWithdrawSourceResponse): TODO: type description here.
        target (GetWithdrawTargetResponse): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "gateway_id":'gateway_id',
        "amount":'amount',
        "status":'status',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "mtype":'type',
        "source":'source',
        "target":'target',
        "metadata":'metadata',
        "fee":'fee',
        "funding_date":'funding_date',
        "funding_estimated_date":'funding_estimated_date'
    }

    def __init__(self,
                 id=None,
                 gateway_id=None,
                 amount=None,
                 status=None,
                 created_at=None,
                 updated_at=None,
                 mtype=None,
                 source=None,
                 target=None,
                 metadata=None,
                 fee=None,
                 funding_date=None,
                 funding_estimated_date=None):
        """Constructor for the GetWithdrawResponse class"""

        # Initialize members of the class
        self.id = id
        self.gateway_id = gateway_id
        self.amount = amount
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.metadata = metadata
        self.fee = fee
        self.funding_date = APIHelper.RFC3339DateTime(funding_date) if funding_date else None
        self.funding_estimated_date = APIHelper.RFC3339DateTime(funding_estimated_date) if funding_estimated_date else None
        self.mtype = mtype
        self.source = source
        self.target = target


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        gateway_id = dictionary.get('gateway_id')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        mtype = dictionary.get('type')
        source = pagarmecoreapi.models.get_withdraw_source_response.GetWithdrawSourceResponse.from_dictionary(dictionary.get('source')) if dictionary.get('source') else None
        target = pagarmecoreapi.models.get_withdraw_target_response.GetWithdrawTargetResponse.from_dictionary(dictionary.get('target')) if dictionary.get('target') else None
        metadata = dictionary.get('metadata')
        fee = dictionary.get('fee')
        funding_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("funding_date")).datetime if dictionary.get("funding_date") else None
        funding_estimated_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("funding_estimated_date")).datetime if dictionary.get("funding_estimated_date") else None

        # Return an object of this model
        return cls(id,
                   gateway_id,
                   amount,
                   status,
                   created_at,
                   updated_at,
                   mtype,
                   source,
                   target,
                   metadata,
                   fee,
                   funding_date,
                   funding_estimated_date)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_apple_pay_request
import pagarmecoreapi.models.create_google_pay_request
import pagarmecoreapi.models.create_emv_decrypt_request

class CreateCardPaymentContactlessRequest(object):

    """Implementation of the 'CreateCardPaymentContactlessRequest' model.

    The card payment contactless request

    Attributes:
        mtype (string): The authentication type
        apple_pay (CreateApplePayRequest): The ApplePay encrypted request
        google_pay (CreateGooglePayRequest): The GooglePay encrypted request
        emv (CreateEmvDecryptRequest): The Emv encrypted request

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "apple_pay":'apple_pay',
        "google_pay":'google_pay',
        "emv":'emv'
    }

    def __init__(self,
                 mtype=None,
                 apple_pay=None,
                 google_pay=None,
                 emv=None):
        """Constructor for the CreateCardPaymentContactlessRequest class"""

        # Initialize members of the class
        self.mtype = mtype
        self.apple_pay = apple_pay
        self.google_pay = google_pay
        self.emv = emv


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get('type')
        apple_pay = pagarmecoreapi.models.create_apple_pay_request.CreateApplePayRequest.from_dictionary(dictionary.get('apple_pay')) if dictionary.get('apple_pay') else None
        google_pay = pagarmecoreapi.models.create_google_pay_request.CreateGooglePayRequest.from_dictionary(dictionary.get('google_pay')) if dictionary.get('google_pay') else None
        emv = pagarmecoreapi.models.create_emv_decrypt_request.CreateEmvDecryptRequest.from_dictionary(dictionary.get('emv')) if dictionary.get('emv') else None

        # Return an object of this model
        return cls(mtype,
                   apple_pay,
                   google_pay,
                   emv)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class GetAntifraudResponse(object):

    """Implementation of the 'GetAntifraudResponse' model.

    TODO: type model description here.

    Attributes:
        status (string): TODO: type description here.
        return_code (string): TODO: type description here.
        return_message (string): TODO: type description here.
        provider_name (string): TODO: type description here.
        score (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "status":'status',
        "return_code":'return_code',
        "return_message":'return_message',
        "provider_name":'provider_name',
        "score":'score'
    }

    def __init__(self,
                 status=None,
                 return_code=None,
                 return_message=None,
                 provider_name=None,
                 score=None):
        """Constructor for the GetAntifraudResponse class"""

        # Initialize members of the class
        self.status = status
        self.return_code = return_code
        self.return_message = return_message
        self.provider_name = provider_name
        self.score = score


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        status = dictionary.get('status')
        return_code = dictionary.get('return_code')
        return_message = dictionary.get('return_message')
        provider_name = dictionary.get('provider_name')
        score = dictionary.get('score')

        # Return an object of this model
        return cls(status,
                   return_code,
                   return_message,
                   provider_name,
                   score)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateIncrementRequest(object):

    """Implementation of the 'CreateIncrementRequest' model.

    Request for creating a new increment

    Attributes:
        value (float): The increment value
        increment_type (string): Increment type. Can be either flat or
            percentage.
        item_id (string): The item where the increment will be applied
        cycles (int): Number of cycles that the increment will be applied
        description (string): Description

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "value":'value',
        "increment_type":'increment_type',
        "item_id":'item_id',
        "cycles":'cycles',
        "description":'description'
    }

    def __init__(self,
                 value=None,
                 increment_type=None,
                 item_id=None,
                 cycles=None,
                 description=None):
        """Constructor for the CreateIncrementRequest class"""

        # Initialize members of the class
        self.value = value
        self.increment_type = increment_type
        self.item_id = item_id
        self.cycles = cycles
        self.description = description


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        value = dictionary.get('value')
        increment_type = dictionary.get('increment_type')
        item_id = dictionary.get('item_id')
        cycles = dictionary.get('cycles')
        description = dictionary.get('description')

        # Return an object of this model
        return cls(value,
                   increment_type,
                   item_id,
                   cycles,
                   description)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_card_request
import pagarmecoreapi.models.create_payment_authentication_request
import pagarmecoreapi.models.create_card_payment_contactless_request

class CreateDebitCardPaymentRequest(object):

    """Implementation of the 'CreateDebitCardPaymentRequest' model.

    The settings for creating a debit card payment

    Attributes:
        statement_descriptor (string): The text that will be shown on the
            debit card's statement
        card (CreateCardRequest): Debit card data
        card_id (string): The debit card id
        card_token (string): The debit card token
        recurrence (bool): Indicates a recurrence
        authentication (CreatePaymentAuthenticationRequest): The payment
            authentication request
        token (CreateCardPaymentContactlessRequest): The Debit card payment
            token request

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "statement_descriptor":'statement_descriptor',
        "card":'card',
        "card_id":'card_id',
        "card_token":'card_token',
        "recurrence":'recurrence',
        "authentication":'authentication',
        "token":'token'
    }

    def __init__(self,
                 statement_descriptor=None,
                 card=None,
                 card_id=None,
                 card_token=None,
                 recurrence=None,
                 authentication=None,
                 token=None):
        """Constructor for the CreateDebitCardPaymentRequest class"""

        # Initialize members of the class
        self.statement_descriptor = statement_descriptor
        self.card = card
        self.card_id = card_id
        self.card_token = card_token
        self.recurrence = recurrence
        self.authentication = authentication
        self.token = token


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        statement_descriptor = dictionary.get('statement_descriptor')
        card = pagarmecoreapi.models.create_card_request.CreateCardRequest.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None
        card_id = dictionary.get('card_id')
        card_token = dictionary.get('card_token')
        recurrence = dictionary.get('recurrence')
        authentication = pagarmecoreapi.models.create_payment_authentication_request.CreatePaymentAuthenticationRequest.from_dictionary(dictionary.get('authentication')) if dictionary.get('authentication') else None
        token = pagarmecoreapi.models.create_card_payment_contactless_request.CreateCardPaymentContactlessRequest.from_dictionary(dictionary.get('token')) if dictionary.get('token') else None

        # Return an object of this model
        return cls(statement_descriptor,
                   card,
                   card_id,
                   card_token,
                   recurrence,
                   authentication,
                   token)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_address_request
import pagarmecoreapi.models.create_phones_request

class CreateCustomerRequest(object):

    """Implementation of the 'CreateCustomerRequest' model.

    Request for creating a new customer

    Attributes:
        name (string): Name
        email (string): Email
        document (string): Document number. Only numbers, no special
            characters.
        mtype (string): Person type. Can be either 'individual' or 'company'
        address (CreateAddressRequest): The customer's address
        metadata (dict<object, string>): Metadata
        phones (CreatePhonesRequest): TODO: type description here.
        code (string): Customer code
        gender (string): Customer Gender
        document_type (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "email":'email',
        "document":'document',
        "mtype":'type',
        "address":'address',
        "metadata":'metadata',
        "phones":'phones',
        "code":'code',
        "gender":'gender',
        "document_type":'document_type'
    }

    def __init__(self,
                 name=None,
                 email=None,
                 document=None,
                 mtype=None,
                 address=None,
                 metadata=None,
                 phones=None,
                 code=None,
                 gender=None,
                 document_type=None):
        """Constructor for the CreateCustomerRequest class"""

        # Initialize members of the class
        self.name = name
        self.email = email
        self.document = document
        self.mtype = mtype
        self.address = address
        self.metadata = metadata
        self.phones = phones
        self.code = code
        self.gender = gender
        self.document_type = document_type


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        email = dictionary.get('email')
        document = dictionary.get('document')
        mtype = dictionary.get('type')
        address = pagarmecoreapi.models.create_address_request.CreateAddressRequest.from_dictionary(dictionary.get('address')) if dictionary.get('address') else None
        metadata = dictionary.get('metadata')
        phones = pagarmecoreapi.models.create_phones_request.CreatePhonesRequest.from_dictionary(dictionary.get('phones')) if dictionary.get('phones') else None
        code = dictionary.get('code')
        gender = dictionary.get('gender')
        document_type = dictionary.get('document_type')

        # Return an object of this model
        return cls(name,
                   email,
                   document,
                   mtype,
                   address,
                   metadata,
                   phones,
                   code,
                   gender,
                   document_type)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper
from pagarmecoreapi.configuration import Configuration
from pagarmecoreapi.controllers.base_controller import BaseController
from pagarmecoreapi.http.auth.basic_auth import BasicAuth
from pagarmecoreapi.models.list_order_response import ListOrderResponse
from pagarmecoreapi.models.get_order_item_response import GetOrderItemResponse
from pagarmecoreapi.models.get_order_response import GetOrderResponse

class OrdersController(BaseController):

    """A Controller to access Endpoints in the pagarmecoreapi API."""


    def get_orders(self,
                   page=None,
                   size=None,
                   code=None,
                   status=None,
                   created_since=None,
                   created_until=None,
                   customer_id=None):
        """Does a GET request to /orders.

        Gets all orders

        Args:
            page (int, optional): Page number
            size (int, optional): Page size
            code (string, optional): Filter for order's code
            status (string, optional): Filter for order's status
            created_since (datetime, optional): Filter for order's creation
                date start range
            created_until (datetime, optional): Filter for order's creation
                date end range
            customer_id (string, optional): Filter for order's customer id

        Returns:
            ListOrderResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'page': page,
            'size': size,
            'code': code,
            'status': status,
            'created_since': APIHelper.when_defined(APIHelper.RFC3339DateTime, created_since),
            'created_until': APIHelper.when_defined(APIHelper.RFC3339DateTime, created_until),
            'customer_id': customer_id
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListOrderResponse.from_dictionary)

    def update_order_item(self,
                          order_id,
                          item_id,
                          request,
                          idempotency_key=None):
        """Does a PUT request to /orders/{orderId}/items/{itemId}.

        TODO: type endpoint description here.

        Args:
            order_id (string): Order Id
            item_id (string): Item Id
            request (UpdateOrderItemRequest): Item Model
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetOrderItemResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders/{orderId}/items/{itemId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'orderId': order_id,
            'itemId': item_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderItemResponse.from_dictionary)

    def delete_all_order_items(self,
                               order_id,
                               idempotency_key=None):
        """Does a DELETE request to /orders/{orderId}/items.

        TODO: type endpoint description here.

        Args:
            order_id (string): Order Id
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetOrderResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders/{orderId}/items'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'orderId': order_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderResponse.from_dictionary)

    def delete_order_item(self,
                          order_id,
                          item_id,
                          idempotency_key=None):
        """Does a DELETE request to /orders/{orderId}/items/{itemId}.

        TODO: type endpoint description here.

        Args:
            order_id (string): Order Id
            item_id (string): Item Id
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetOrderItemResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders/{orderId}/items/{itemId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'orderId': order_id,
            'itemId': item_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderItemResponse.from_dictionary)

    def close_order(self,
                    id,
                    request,
                    idempotency_key=None):
        """Does a PATCH request to /orders/{id}/closed.

        TODO: type endpoint description here.

        Args:
            id (string): Order Id
            request (UpdateOrderStatusRequest): Update Order Model
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetOrderResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders/{id}/closed'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'id': id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderResponse.from_dictionary)

    def create_order(self,
                     body,
                     idempotency_key=None):
        """Does a POST request to /orders.

        Creates a new Order

        Args:
            body (CreateOrderRequest): Request for creating an order
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetOrderResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderResponse.from_dictionary)

    def create_order_item(self,
                          order_id,
                          request,
                          idempotency_key=None):
        """Does a POST request to /orders/{orderId}/items.

        TODO: type endpoint description here.

        Args:
            order_id (string): Order Id
            request (CreateOrderItemRequest): Order Item Model
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetOrderItemResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders/{orderId}/items'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'orderId': order_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderItemResponse.from_dictionary)

    def get_order_item(self,
                       order_id,
                       item_id):
        """Does a GET request to /orders/{orderId}/items/{itemId}.

        TODO: type endpoint description here.

        Args:
            order_id (string): Order Id
            item_id (string): Item Id

        Returns:
            GetOrderItemResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders/{orderId}/items/{itemId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'orderId': order_id,
            'itemId': item_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderItemResponse.from_dictionary)

    def update_order_metadata(self,
                              order_id,
                              request,
                              idempotency_key=None):
        """Does a PATCH request to /Orders/{order_id}/metadata.

        Updates the metadata from an order

        Args:
            order_id (string): The order id
            request (UpdateMetadataRequest): Request for updating the order
                metadata
            idempotency_key (string, optional): TODO: type description here.
                Example: 

        Returns:
            GetOrderResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/Orders/{order_id}/metadata'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'order_id': order_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'idempotency-key': idempotency_key
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderResponse.from_dictionary)

    def get_order(self,
                  order_id):
        """Does a GET request to /orders/{order_id}.

        Gets an order

        Args:
            order_id (string): Order id

        Returns:
            GetOrderResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/orders/{order_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'order_id': order_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetOrderResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateCardOptionsRequest(object):

    """Implementation of the 'CreateCardOptionsRequest' model.

    Options for creating the card

    Attributes:
        verify_card (bool): Indicates if the card should be verified before
            creation. If true, executes an authorization before saving the
            card.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "verify_card":'verify_card'
    }

    def __init__(self,
                 verify_card=None):
        """Constructor for the CreateCardOptionsRequest class"""

        # Initialize members of the class
        self.verify_card = verify_card


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        verify_card = dictionary.get('verify_card')

        # Return an object of this model
        return cls(verify_card)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.get_gateway_error_response

class GetGatewayResponseResponse(object):

    """Implementation of the 'GetGatewayResponseResponse' model.

    The Transaction Gateway Response

    Attributes:
        code (string): The error code
        errors (list of GetGatewayErrorResponse): The gateway response errors
            list

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "code":'code',
        "errors":'errors'
    }

    def __init__(self,
                 code=None,
                 errors=None):
        """Constructor for the GetGatewayResponseResponse class"""

        # Initialize members of the class
        self.code = code
        self.errors = errors


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        code = dictionary.get('code')
        errors = None
        if dictionary.get('errors') != None:
            errors = list()
            for structure in dictionary.get('errors'):
                errors.append(pagarmecoreapi.models.get_gateway_error_response.GetGatewayErrorResponse.from_dictionary(structure))

        # Return an object of this model
        return cls(code,
                   errors)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.get_customer_response

class GetCheckoutPaymentSettingsResponse(object):

    """Implementation of the 'GetCheckoutPaymentSettingsResponse' model.

    Checkout Payment Settings Response

    Attributes:
        success_url (string): Success Url
        payment_url (string): Payment Url
        accepted_payment_methods (list of string): Accepted Payment Methods
        status (string): Status
        customer (GetCustomerResponse): Customer
        amount (int): Payment amount
        default_payment_method (string): Default Payment Method
        gateway_affiliation_id (string): Gateway Affiliation Id

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "success_url":'success_url',
        "payment_url":'payment_url',
        "accepted_payment_methods":'accepted_payment_methods',
        "status":'status',
        "customer":'customer',
        "amount":'amount',
        "default_payment_method":'default_payment_method',
        "gateway_affiliation_id":'gateway_affiliation_id'
    }

    def __init__(self,
                 success_url=None,
                 payment_url=None,
                 accepted_payment_methods=None,
                 status=None,
                 customer=None,
                 amount=None,
                 default_payment_method=None,
                 gateway_affiliation_id=None):
        """Constructor for the GetCheckoutPaymentSettingsResponse class"""

        # Initialize members of the class
        self.success_url = success_url
        self.payment_url = payment_url
        self.accepted_payment_methods = accepted_payment_methods
        self.status = status
        self.customer = customer
        self.amount = amount
        self.default_payment_method = default_payment_method
        self.gateway_affiliation_id = gateway_affiliation_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        success_url = dictionary.get('success_url')
        payment_url = dictionary.get('payment_url')
        accepted_payment_methods = dictionary.get('accepted_payment_methods')
        status = dictionary.get('status')
        customer = pagarmecoreapi.models.get_customer_response.GetCustomerResponse.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        amount = dictionary.get('amount')
        default_payment_method = dictionary.get('default_payment_method')
        gateway_affiliation_id = dictionary.get('gateway_affiliation_id')

        # Return an object of this model
        return cls(success_url,
                   payment_url,
                   accepted_payment_methods,
                   status,
                   customer,
                   amount,
                   default_payment_method,
                   gateway_affiliation_id)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.api_helper import APIHelper
import pagarmecoreapi.models.pix_additional_information

class CreatePixPaymentRequest(object):

    """Implementation of the 'CreatePixPaymentRequest' model.

    Contains information to create a pix payment

    Attributes:
        expires_at (datetime): Datetime when pix payment will expire
        expires_in (int): Seconds until pix payment expires
        additional_information (list of PixAdditionalInformation): Pix
            additional information

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "expires_at":'expires_at',
        "expires_in":'expires_in',
        "additional_information":'additional_information'
    }

    def __init__(self,
                 expires_at=None,
                 expires_in=None,
                 additional_information=None):
        """Constructor for the CreatePixPaymentRequest class"""

        # Initialize members of the class
        self.expires_at = APIHelper.RFC3339DateTime(expires_at) if expires_at else None
        self.expires_in = expires_in
        self.additional_information = additional_information


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        expires_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("expires_at")).datetime if dictionary.get("expires_at") else None
        expires_in = dictionary.get('expires_in')
        additional_information = None
        if dictionary.get('additional_information') != None:
            additional_information = list()
            for structure in dictionary.get('additional_information'):
                additional_information.append(pagarmecoreapi.models.pix_additional_information.PixAdditionalInformation.from_dictionary(structure))

        # Return an object of this model
        return cls(expires_at,
                   expires_in,
                   additional_information)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from pagarmecoreapi.decorators import lazy_property
from pagarmecoreapi.configuration import Configuration
from pagarmecoreapi.controllers.plans_controller import PlansController
from pagarmecoreapi.controllers.subscriptions_controller import SubscriptionsController
from pagarmecoreapi.controllers.invoices_controller import InvoicesController
from pagarmecoreapi.controllers.orders_controller import OrdersController
from pagarmecoreapi.controllers.customers_controller import CustomersController
from pagarmecoreapi.controllers.recipients_controller import RecipientsController
from pagarmecoreapi.controllers.charges_controller import ChargesController
from pagarmecoreapi.controllers.transfers_controller import TransfersController
from pagarmecoreapi.controllers.tokens_controller import TokensController
from pagarmecoreapi.controllers.sellers_controller import SellersController
from pagarmecoreapi.controllers.transactions_controller import TransactionsController


class PagarmecoreapiClient(object):

    config = Configuration

    @lazy_property
    def plans(self):
        return PlansController()

    @lazy_property
    def subscriptions(self):
        return SubscriptionsController()

    @lazy_property
    def invoices(self):
        return InvoicesController()

    @lazy_property
    def orders(self):
        return OrdersController()

    @lazy_property
    def customers(self):
        return CustomersController()

    @lazy_property
    def recipients(self):
        return RecipientsController()

    @lazy_property
    def charges(self):
        return ChargesController()

    @lazy_property
    def transfers(self):
        return TransfersController()

    @lazy_property
    def tokens(self):
        return TokensController()

    @lazy_property
    def sellers(self):
        return SellersController()

    @lazy_property
    def transactions(self):
        return TransactionsController()


    def __init__(self,
                 basic_auth_user_name=None,
                 basic_auth_password=None):
        if basic_auth_user_name is not None:
            Configuration.basic_auth_user_name = basic_auth_user_name
        if basic_auth_password is not None:
            Configuration.basic_auth_password = basic_auth_password

